@@ -111,7 +111,7 @@ class Api:
             auth = self._auth
 
             if url and self.sleep_on_rate_limit:
-                limit = self.rate_limit.get_limit(url=url)
+                limit = self.rate_limit.get_limit(url=url, method=verb)
                 if limit.remaining == 0:
                     s_time = max((limit.reset - time.time()), 0) + 10.0
                     logger.debug(
@@ -131,7 +131,7 @@ class Api:
         )
 
         if url and self.rate_limit:
-            self.rate_limit.set_limit(url=url, headers=resp.headers)
+            self.rate_limit.set_limit(url=url, headers=resp.headers, method=verb)
 
         return resp
 
@@ -890,6 +890,50 @@ class Api:
         data = self._parse_response(resp)
         return data
 
+    def get_blocking_users(
+        self,
+        user_id: str,
+        *,
+        expansions: Optional[Union[str, List, Tuple]] = None,
+        user_fields: Optional[Union[str, List, Tuple]] = None,
+        tweet_fields: Optional[Union[str, List, Tuple]] = None,
+        max_results: Optional[int] = None,
+        pagination_token: Optional[str] = None,
+        return_json: bool = False,
+    ):
+        """
+        Returns a list of users who are blocked by the specified user ID.
+
+        :param user_id: The user ID whose blocking you would like to retrieve.
+        :param expansions: Fields for the expansions.
+        :param user_fields: Fields for the user object.
+        :param tweet_fields: Fields for the tweet object.
+        :param max_results: The maximum number of results to be returned per page. Number between 1 and the 1000.
+        By default, each page will return 100 results.
+        :param pagination_token: Token for the pagination.
+        :param return_json: Type for returned data. If you set True JSON data will be returned.
+        :return:
+            - data: data for the blocking.
+            - includes: expansions data.
+            - meta: pagination details
+        """
+        args = {
+            "expansions": enf_comma_separated(name="expansions", value=expansions),
+            "user.fields": enf_comma_separated(name="user_fields", value=user_fields),
+            "tweet.fields": enf_comma_separated(
+                name="tweet_fields", value=tweet_fields
+            ),
+            "max_results": max_results,
+            "pagination_token": pagination_token,
+        }
+        return self._get(
+            url=f"{self.BASE_URL_V2}/users/{user_id}/blocking",
+            params=args,
+            cls=md.User,
+            multi=True,
+            return_json=return_json,
+        )
+
     def unblock_user(self, user_id: str, target_user_id: str) -> dict:
         """
         Allows user to unblock another user.
@@ -940,3 +984,98 @@ class Api:
         )
         data = self._parse_response(resp=resp)
         return data
+
+    def get_user_liked_tweets(
+        self,
+        user_id: str,
+        *,
+        pagination_token: Optional[str] = None,
+        max_results: Optional[int] = None,
+        tweet_fields: Optional[Union[str, List, Tuple]] = None,
+        expansions: Optional[Union[str, List, Tuple]] = None,
+        user_fields: Optional[Union[str, List, Tuple]] = None,
+        media_fields: Optional[Union[str, List, Tuple]] = None,
+        place_fields: Optional[Union[str, List, Tuple]] = None,
+        poll_fields: Optional[Union[str, List, Tuple]] = None,
+        return_json: bool = False,
+    ):
+        """
+        Get information about a user’s liked Tweets.
+
+        :param user_id: The user ID whose liked tweets you would like to retrieve.
+        :param expansions: Fields for the expansions.
+        :param pagination_token: Token for the pagination.
+        :param max_results: The maximum number of results to be returned per page. Number between 1 and the 1000.
+        By default, each page will return 100 results.
+        :param tweet_fields: Fields for the tweet object.
+        :param user_fields: Fields for the user object, Expansion required.
+        :param media_fields: Fields for the media object, Expansion required.
+        :param place_fields: Fields for the place object, Expansion required.
+        :param poll_fields: Fields for the poll object, Expansion required.
+        :param return_json: Type for returned data. If you set True JSON data will be returned.
+        :return:
+            - data: data for the tweets.
+            - includes: expansions data.
+            - meta: pagination details
+        """
+        args = {
+            "expansions": enf_comma_separated(name="expansions", value=expansions),
+            "tweet.fields": enf_comma_separated(
+                name="tweet_fields", value=tweet_fields
+            ),
+            "user.fields": enf_comma_separated(name="user_fields", value=user_fields),
+            "media.fields": enf_comma_separated(
+                name="media_fields", value=media_fields
+            ),
+            "place.fields": enf_comma_separated(
+                name="place_fields", value=place_fields
+            ),
+            "poll.fields": enf_comma_separated(name="poll_fields", value=poll_fields),
+            "max_results": max_results,
+            "pagination_token": pagination_token,
+        }
+        return self._get(
+            url=f"{self.BASE_URL_V2}/users/{user_id}/liked_tweets",
+            params=args,
+            cls=md.Tweet,
+            multi=True,
+            return_json=return_json,
+        )
+
+    def get_tweet_liking_users(
+        self,
+        tweet_id: str,
+        *,
+        user_fields: Optional[Union[str, List, Tuple]] = None,
+        expansions: Optional[Union[str, List, Tuple]] = None,
+        tweet_fields: Optional[Union[str, List, Tuple]] = None,
+        return_json: bool = False,
+    ):
+        """
+        Get information about a Tweet’s liking users.
+
+        :param tweet_id: The tweet ID whose liking users you would like to retrieve.
+        :param expansions: Fields for the expansions.
+        By default, each page will return 100 results.
+        :param tweet_fields: Fields for the tweet object.
+        :param user_fields: Fields for the user object, Expansion required.
+        :param return_json: Type for returned data. If you set True JSON data will be returned.
+        :return:
+            - data: data for the users.
+            - includes: expansions data.
+            - meta: pagination details
+        """
+        args = {
+            "expansions": enf_comma_separated(name="expansions", value=expansions),
+            "user.fields": enf_comma_separated(name="user_fields", value=user_fields),
+            "tweet.fields": enf_comma_separated(
+                name="tweet_fields", value=tweet_fields
+            ),
+        }
+        return self._get(
+            url=f"{self.BASE_URL_V2}/tweets/{tweet_id}/liking_users",
+            params=args,
+            cls=md.User,
+            multi=True,
+            return_json=return_json,
+        )
